GNSS-A Level 2 Data Standard
============================

The following contains the data field specification
for the Level 2 data standard for the GNSS-A project.

Current version: v1, based on the discussions from the
working group see the following `document <https://hal.science/hal-04319233/document>`_.

.. autopydantic_model:: gnatss.dataspec.v1.DataV1
